==> github-widget2-1.0.0.tgz: package/lib/test/issue.test.js <==
'use strict';

var _jsxFileName = '../../src/test/issue.test.jsx';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Issue = require('../components/Issue/Issue');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ownProps = { widgetId: 'github' };
var state = {
  widgets: {
    byId: {
      github: {
        issues: {
          issuesById: {
            238923429: {
              assignedTo: [['Gwillison415', 'https://avatars2.githubusercontent.com/u/22106099?v=4']],
              labels: ['duplicate', 'help wanted', 'question'],
              number: 16,
              title: 'login tst JWT token'
            }
          }
        }
      }
    }
  }
};

describe('Issue entry component', function () {
  it('should render a component with props as specified ', function () {
    var _getDescription = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issue.Issue, {
      id: ownProps.widgetId,
      labels: state.widgets.byId.github.issues.issuesById[238923429].labels,
      issueId: 238923429,
      number: 16,
      assignedTo: state.widgets.byId.github.issues.issuesById[238923429].assignedTo[0],
      title: 'login tst JWT token',
      getDescription: function getDescription() {
        _getDescription();
      },
      __source: {
        fileName: _jsxFileName,
        lineNumber: 31
      },
      __self: undefined
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it('map\'s given State To Props ', function () {
    var expected = {
      assignedTo: [['Gwillison415', 'https://avatars2.githubusercontent.com/u/22106099?v=4']],
      labels: ['duplicate', 'help wanted', 'question'],
      number: 16,
      title: 'login tst JWT token'
    };

    expect((0, _Issue.mapStateToProps)(state, { issueId: 238923429, widgetId: 'github' })).toEqual(expected);
  });

  it('Should have a Cart Header in the center', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issue.Issue, {
      title: 'login tst JWT token',
      issueId: 238923429,
      labels: state.widgets.byId.github.issues.issuesById[238923429].labels,
      number: 16,
      assignedTo: ['Gwillison415', 'https://avatars2.githubusercontent.com/u/22106099?v=4'],
      __source: {
        fileName: _jsxFileName,
        lineNumber: 57
      },
      __self: undefined
    }));
    expect(component.find('.aligned').exists()).toBe(true);
  });
});

==> github-widget2-1.0.4.tgz: package/lib/test/issue.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _Issue = require('../components/Issue/Issue');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ownProps = { widgetId: 'github' };
var state = {
  widgets: {
    byId: {
      github: {
        issues: {
          issuesById: {
            238923429: {
              assignedTo: [['Gwillison415', 'https://avatars2.githubusercontent.com/u/22106099?v=4']],
              labels: ['duplicate', 'help wanted', 'question'],
              number: 16,
              title: 'login tst JWT token'
            }
          }
        }
      }
    }
  }
};

describe('Issue entry component', function () {
  it('should render a component with props as specified ', function () {
    var _getDescription = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issue.Issue, {
      id: ownProps.widgetId,
      labels: state.widgets.byId.github.issues.issuesById[238923429].labels,
      issueId: 238923429,
      number: 16,
      assignedTo: state.widgets.byId.github.issues.issuesById[238923429].assignedTo[0],
      title: 'login tst JWT token',
      getDescription: function getDescription() {
        _getDescription();
      }
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it('map\'s given State To Props ', function () {
    var expected = {
      assignedTo: [['Gwillison415', 'https://avatars2.githubusercontent.com/u/22106099?v=4']],
      labels: ['duplicate', 'help wanted', 'question'],
      number: 16,
      title: 'login tst JWT token'
    };

    expect((0, _Issue.mapStateToProps)(state, { issueId: 238923429, widgetId: 'github' })).toEqual(expected);
  });

  it('Should have a Cart Header in the center', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_Issue.Issue, {
      title: 'login tst JWT token',
      issueId: 238923429,
      labels: state.widgets.byId.github.issues.issuesById[238923429].labels,
      number: 16,
      assignedTo: ['Gwillison415', 'https://avatars2.githubusercontent.com/u/22106099?v=4']
    }));
    expect(component.find('.aligned').exists()).toBe(true);
  });
});
